@@ -1,3 +1,4 @@
+import { Trans } from '@grafana/i18n';
 import { LinkButton } from '@grafana/ui';
 
 export interface Props {
@@ -12,7 +13,7 @@ export const CustomerSupportButton = ({ orgSlug, licenseId }: Props) => {
   }
   return (
     <LinkButton href={href} target="_blank" rel="noopener noreferrer">
-      Contact customer support
+      <Trans i18nKey="licensing.customer-support-button.contact-customer-support">Contact customer support</Trans>
     </LinkButton>
   );
 };
